<div class="d-flex align-items-center justify-content-between my-5">
  <div class="{{header_class}}">
    {{header_text}} 
    {% if badge_text %}<span class='badge badge-pill badge-{{badge_class}}'>{{badge_text}}</span>{% endif %}
  </div>
  {% block controls %}
  {% endblock %}  
</div>